@@ -51,7 +51,7 @@ BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH               = os.environ['BIGQUERY_SERVI
 BIGQUERY_SERVICE_CREDENTIAL_PATH                    = os.path.abspath(os.path.dirname(config_path.__file__)) +'/'+ BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH
 
 
-BASE_URL                                            = os.environ.get('BASE_URL')
+ANALYTICS_BASE_URL                                  = os.environ.get('ANALYTICS_BASE_URL')
 #BASE_URL                                            = 'http://a66fac3caa6b.ngrok.io'
 
 STREAM_DATA_PAGE_SIZE                               = 100
