@@ -26,7 +26,11 @@ class QueryBaseResource(Resource):
         logger.info('query=%s', query)
         
         bg_client       = create_bigquery_client()
-        job_result_rows = execute_query(bg_client, query)
+        try:
+            job_result_rows = execute_query(bg_client, query)
+        except:
+            job_result_rows = []
+            logger.error('Failed to execute query due to %s', get_tracelog())
         
         query_result    = self.process_query_result(job_result_rows)
         
